@@ -4,4 +4,4 @@ utils::globalVariables(c("AE_ONSET_DT_INT", "AE_SEV_GD", "AE_VERBATIM_TRM_TXT",
                          "cl", "desc", "drug1_ae", "gender_code", "group", "ind", "indH", "indH_per", "instance", "join",
                          "label", "median", "na.fail", "stopCluster", "time_max", "time_median", "time_min", "where",
                          "ID", "est", "term", "lower", "upper", "significance", "model1", "reorder", "ID_label", 
-                         "instances", "hp_instances"))
\ No newline at end of file
+                         "instances", "hp_instances", "AE_Grade", "AE_Detail", "Study", "n_distinct_subjects"))
\ No newline at end of file
